pub struct DropGuard {
pub(super) inner: Option<CancellationToken>,
}Expand description
A wrapper for cancellation token which automatically cancels
it on drop. It is created using drop_guard method on the CancellationToken.
Fields
inner: Option<CancellationToken>Implementations
Sourceimpl DropGuard
impl DropGuard
Sourcepub fn token(&self) -> &CancellationToken
pub fn token(&self) -> &CancellationToken
Returns a reference to the cancellation token wrapped by this guard.
Sourcepub fn disarm(self) -> CancellationToken
pub fn disarm(self) -> CancellationToken
Returns stored cancellation token and removes this drop guard instance (i.e. it will no longer cancel token). Other guards for this token are not affected.